@@ -13,14 +13,14 @@
 #include <sys/errno.h>
 #include <tqtimer.h>
 #include <kapp.h>
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include "kdirtree.h"
 #include "kdirtreeiterators.h"
 #include "kdirtreeview.h"
 #include "kdirsaver.h"
-#include "kio/job.h"
-#include "kio/netaccess.h"
+#include "tdeio/job.h"
+#include "tdeio/netaccess.h"
 
 #define HAVE_STUPID_COMPILER 0
 
@@ -55,7 +55,7 @@ KFileInfo::KFileInfo( const TQString &	filenameWithoutPath,
     , _next( 0 )
     , _tree( tree )
 {
-    CHECK_PTR( statInfo );
+    TQ_CHECK_PTR( statInfo );
 
     _isLocalFile = true;
     _name	 = filenameWithoutPath;
@@ -107,7 +107,7 @@ KFileInfo::KFileInfo(  const KFileItem	* fileItem,
     , _next( 0 )
     , _tree( tree )
 {
-    CHECK_PTR( fileItem );
+    TQ_CHECK_PTR( fileItem );
 
     _isLocalFile = fileItem->isLocalFile();
     _name	 = parent ? fileItem->name() : fileItem->url().url();
@@ -140,7 +140,7 @@ KFileInfo::KFileInfo(  const KFileItem	* fileItem,
 	_isSparseFile = false;
     }
 
-    _mtime	 = fileItem->time( KIO::UDS_MODIFICATION_TIME );
+    _mtime	 = fileItem->time( TDEIO::UDS_MODIFICATION_TIME );
 }
 
 
@@ -576,7 +576,7 @@ KDirInfo::isBusy()
 void
 KDirInfo::insertChild( KFileInfo *newChild )
 {
-    CHECK_PTR( newChild );
+    TQ_CHECK_PTR( newChild );
 
     if ( newChild->isDir() || _dotEntry == 0 || _isDotEntry )
     {
@@ -859,7 +859,7 @@ KLocalDirReadJob::startReading()
     struct stat		statInfo;
     TQString		dirName	 = _dir->url();
 
-    if ( ( _diskDir = opendir( dirName ) ) )
+    if ( ( _diskDir = opendir( dirName.local8Bit() ) ) )
     {
 	_tree->sendProgressInfo( dirName );
 	_dir->setReadState( KDirReading );
@@ -873,7 +873,7 @@ KLocalDirReadJob::startReading()
 	    {
 		TQString fullName = dirName + "/" + entryName;
 
-		if ( lstat( fullName, &statInfo ) == 0 )	// lstat() OK
+		if ( lstat( fullName.local8Bit(), &statInfo ) == 0 )	// lstat() OK
 		{
 		    if ( S_ISDIR( statInfo.st_mode ) )	// directory child?
 		    {
@@ -957,7 +957,7 @@ KLocalDirReadJob::stat( const KURL & 	url,
 {
     struct stat statInfo;
 
-    if ( lstat( url.path(), &statInfo ) == 0 )		// lstat() OK
+    if ( lstat( url.path().local8Bit(), &statInfo ) == 0 )		// lstat() OK
     {
 	TQString name = parent ? url.filename() : url.path();
 
@@ -1010,23 +1010,23 @@ KAnyDirReadJob::startReading()
 	kdWarning() << k_funcinfo << "URL malformed: " << _dir->url() << endl;
     }
 
-    _job = KIO::listDir( url,
+    _job = TDEIO::listDir( url,
 			 false );	// showProgressInfo
 
-    connect( _job, TQT_SIGNAL( entries( KIO::Job *, const KIO::UDSEntryList& ) ),
-             this, TQT_SLOT  ( entries( KIO::Job *, const KIO::UDSEntryList& ) ) );
+    connect( _job, TQ_SIGNAL( entries( TDEIO::Job *, const TDEIO::UDSEntryList& ) ),
+             this, TQ_SLOT  ( entries( TDEIO::Job *, const TDEIO::UDSEntryList& ) ) );
 
-    connect( _job, TQT_SIGNAL( result  ( KIO::Job * ) ),
-	     this, TQT_SLOT  ( finished( KIO::Job * ) ) );
+    connect( _job, TQ_SIGNAL( result  ( TDEIO::Job * ) ),
+	     this, TQ_SLOT  ( finished( TDEIO::Job * ) ) );
 
-    connect( _job, TQT_SIGNAL( canceled( KIO::Job * ) ),
-	     this, TQT_SLOT  ( finished( KIO::Job * ) ) );
+    connect( _job, TQ_SIGNAL( canceled( TDEIO::Job * ) ),
+	     this, TQ_SLOT  ( finished( TDEIO::Job * ) ) );
 }
 
 
 void
-KAnyDirReadJob::entries ( KIO::Job *			job,
-			  const KIO::UDSEntryList &	entryList )
+KAnyDirReadJob::entries ( TDEIO::Job *			job,
+			  const TDEIO::UDSEntryList &	entryList )
 {
     NOT_USED( job );
     KURL url( _dir->url() );	// Cache this - it's expensive!
@@ -1036,7 +1036,7 @@ KAnyDirReadJob::entries ( KIO::Job *			job,
 	kdWarning() << k_funcinfo << "URL malformed: " << _dir->url() << endl;
     }
 
-    KIO::UDSEntryListConstIterator it = entryList.begin();
+    TDEIO::UDSEntryListConstIterator it = entryList.begin();
 
     while ( it != entryList.end() )
     {
@@ -1076,7 +1076,7 @@ KAnyDirReadJob::entries ( KIO::Job *			job,
 
 
 void
-KAnyDirReadJob::finished( KIO::Job * job )
+KAnyDirReadJob::finished( TDEIO::Job * job )
 {
     if ( job->error() )
 	_dir->setReadState( KDirError );
@@ -1099,9 +1099,9 @@ KAnyDirReadJob::stat( const KURL & 	url,
 		      KDirTree  * 	tree,
 		      KDirInfo * 	parent )
 {
-    KIO::UDSEntry uds_entry;
+    TDEIO::UDSEntry uds_entry;
 
-    if ( KIO::NetAccess::stat( url, uds_entry, tqApp->mainWidget() ) )	// remote stat() OK?
+    if ( TDEIO::NetAccess::stat( url, uds_entry, tqApp->mainWidget() ) )	// remote stat() OK?
     {
 	KFileItem entry( uds_entry, url,
 			 true,		// determine MIME type on demand
@@ -1128,9 +1128,9 @@ KAnyDirReadJob::stat( const KURL & 	url,
 TQString
 KAnyDirReadJob::owner( KURL url )
 {
-    KIO::UDSEntry uds_entry;
+    TDEIO::UDSEntry uds_entry;
 
-    if ( KIO::NetAccess::stat( url, uds_entry, tqApp->mainWidget() ) )	// remote stat() OK?
+    if ( TDEIO::NetAccess::stat( url, uds_entry, tqApp->mainWidget() ) )	// remote stat() OK?
     {
 	KFileItem entry( uds_entry, url,
 			 true,		// determine MIME type on demand
@@ -1181,7 +1181,7 @@ KDirTree::~KDirTree()
 void
 KDirTree::readConfig()
 {
-    KConfig * config = kapp->config();
+    TDEConfig * config = kapp->config();
     config->setGroup( "Directory Reading" );
 
     _crossFileSystems		= config->readBoolEntry( "CrossFileSystems",     false );
@@ -1231,7 +1231,7 @@ KDirTree::startReading( const KURL & url )
     }
     else
     {
-	// kdDebug() << "Using KIO methods for " << url.url() << endl;
+	// kdDebug() << "Using TDEIO methods for " << url.url() << endl;
 	KURL cleanUrl( url );
 	cleanUrl.cleanPath();	// Resolve relative paths, get rid of multiple '/'
 	_readMethod	= KDirReadKIO;
@@ -1266,7 +1266,7 @@ KDirTree::startReading( const KURL & url )
     }
 
     if ( ! _jobQueue.isEmpty() )
-	TQTimer::singleShot( 0, this, TQT_SLOT( timeSlicedRead() ) );
+	TQTimer::singleShot( 0, this, TQ_SLOT( timeSlicedRead() ) );
 }
 
 
@@ -1348,7 +1348,7 @@ KDirTree::refresh( KFileInfo *subtree )
 	    // Trigger reading as soon as the event loop continues.
 
 	    if ( ! _jobQueue.isEmpty() )
-		TQTimer::singleShot( 0, this, TQT_SLOT( timeSlicedRead() ) );
+		TQTimer::singleShot( 0, this, TQ_SLOT( timeSlicedRead() ) );
 	}
     }
 }
@@ -1402,7 +1402,7 @@ KDirTree::jobFinishedNotify( KDirReadJob *job )
     {
 	// Set up zero-duration timer for the new job.
 
-	TQTimer::singleShot( 0, this, TQT_SLOT( timeSlicedRead() ) );
+	TQTimer::singleShot( 0, this, TQ_SLOT( timeSlicedRead() ) );
     }
 }
 
@@ -1499,7 +1499,7 @@ KDirTree::deleteSubtree( KFileInfo *subtree )
 void
 KDirTree::addJob( KDirReadJob * job )
 {
-    CHECK_PTR( job );
+    TQ_CHECK_PTR( job );
     _jobQueue.enqueue( job );
 }
 
@@ -1556,7 +1556,7 @@ KDirStat::fixedUrl( const TQString & dirtyUrl )
     }
 
 
-    // Strip off the rightmost slash - some kioslaves (e.g. 'tar') can't handle that.
+    // Strip off the rightmost slash - some tdeioslaves (e.g. 'tar') can't handle that.
 
     TQString path = url.path();
 
@@ -1631,6 +1631,6 @@ KDirStat::formatSize( KFileSize lSize )
    return sizeString;
 }
 
-
+#include "kdirtree.moc"
 
 // EOF
