@@ -17,9 +17,9 @@
 #include <tqpopupmenu.h>
 
 #include <kapp.h>
-#include <klocale.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
+#include <tdeglobalsettings.h>
 #include <kicontheme.h>
 #include <kiconloader.h>
 
@@ -88,20 +88,20 @@ KDirTreeView::KDirTreeView( TQWidget * parent )
     setSorting( _totalSizeCol );
 
 
-#define loadIcon(ICON)	KGlobal::iconLoader()->loadIcon( (ICON), KIcon::Small )
+#define loadIcon(ICON)	TDEGlobal::iconLoader()->loadIcon( (ICON), TDEIcon::Small )
 
     _openDirIcon	= loadIcon( "folder_open" 	);
     _closedDirIcon	= loadIcon( "folder"		);
     _openDotEntryIcon	= loadIcon( "folder_orange_open");
     _closedDotEntryIcon	= loadIcon( "folder_orange"	);
     _unreadableDirIcon	= loadIcon( "folder_locked" 	);
-    _mountPointIcon	= loadIcon( "hdd_mount"		);
+    _mountPointIcon	= loadIcon( "drive-harddisk-mounted"		);
     _fileIcon		= loadIcon( "mime_empty"	);
     _symLinkIcon	= loadIcon( "symlink"		);	// The KDE standard link icon is ugly!
     _blockDevIcon	= loadIcon( "blockdevice"	);
     _charDevIcon	= loadIcon( "chardevice"	);
     _fifoIcon		= loadIcon( "socket"		);
-    _stopIcon		= loadIcon( "stop"		);
+    _stopIcon		= loadIcon( "process-stop"	);
     _readyIcon		= TQPixmap();
 
 #undef loadIcon
@@ -111,17 +111,17 @@ KDirTreeView::KDirTreeView( TQWidget * parent )
     ensureContrast();
 
 
-    connect( kapp,	TQT_SIGNAL( kdisplayPaletteChanged()	),
-	     this,	TQT_SLOT  ( paletteChanged()		) );
+    connect( kapp,	TQ_SIGNAL( tdedisplayPaletteChanged()	),
+	     this,	TQ_SLOT  ( paletteChanged()		) );
 
-    connect( this,	TQT_SIGNAL( selectionChanged	( TQListViewItem * ) ),
-	     this,	TQT_SLOT  ( selectItem		( TQListViewItem * ) ) );
+    connect( this,	TQ_SIGNAL( selectionChanged	( TQListViewItem * ) ),
+	     this,	TQ_SLOT  ( selectItem		( TQListViewItem * ) ) );
 
-    connect( this,	TQT_SIGNAL( rightButtonPressed	( TQListViewItem *, const TQPoint &, int ) ),
-	     this,	TQT_SLOT  ( popupContextMenu	( TQListViewItem *, const TQPoint &, int ) ) );
+    connect( this,	TQ_SIGNAL( rightButtonPressed	( TQListViewItem *, const TQPoint &, int ) ),
+	     this,	TQ_SLOT  ( popupContextMenu	( TQListViewItem *, const TQPoint &, int ) ) );
 
-    connect( header(),	TQT_SIGNAL( sizeChange   ( int, int, int ) ),
-	     this,	TQT_SLOT  ( columnResized( int, int, int ) ) );
+    connect( header(),	TQ_SIGNAL( sizeChange   ( int, int, int ) ),
+	     this,	TQ_SLOT  ( columnResized( int, int, int ) ) );
 
    _contextInfo	  = new TQPopupMenu;
    _idContextInfo = _contextInfo->insertItem ( "dummy" );
@@ -221,32 +221,32 @@ KDirTreeView::openURL( KURL url )
 
     // Connect signals
 
-    connect( _tree, TQT_SIGNAL( progressInfo    ( const TQString & ) ),
-	     this,  TQT_SLOT  ( sendProgressInfo( const TQString & ) ) );
+    connect( _tree, TQ_SIGNAL( progressInfo    ( const TQString & ) ),
+	     this,  TQ_SLOT  ( sendProgressInfo( const TQString & ) ) );
 
-    connect( _tree, TQT_SIGNAL( childAdded( KFileInfo * ) ),
-	     this,  TQT_SLOT  ( addChild  ( KFileInfo * ) ) );
+    connect( _tree, TQ_SIGNAL( childAdded( KFileInfo * ) ),
+	     this,  TQ_SLOT  ( addChild  ( KFileInfo * ) ) );
 
-    connect( _tree, TQT_SIGNAL( deletingChild( KFileInfo * ) ),
-	     this,  TQT_SLOT  ( deleteChild  ( KFileInfo * ) ) );
+    connect( _tree, TQ_SIGNAL( deletingChild( KFileInfo * ) ),
+	     this,  TQ_SLOT  ( deleteChild  ( KFileInfo * ) ) );
 
-    connect( _tree, TQT_SIGNAL( startingReading() ),
-	     this,  TQT_SLOT  ( prepareReading()  ) );
+    connect( _tree, TQ_SIGNAL( startingReading() ),
+	     this,  TQ_SLOT  ( prepareReading()  ) );
 
-    connect( _tree, TQT_SIGNAL( finished()     ),
-	     this,  TQT_SLOT  ( slotFinished() ) );
+    connect( _tree, TQ_SIGNAL( finished()     ),
+	     this,  TQ_SLOT  ( slotFinished() ) );
 
-    connect( _tree, TQT_SIGNAL( aborted()     ),
-	     this,  TQT_SLOT  ( slotAborted() ) );
+    connect( _tree, TQ_SIGNAL( aborted()     ),
+	     this,  TQ_SLOT  ( slotAborted() ) );
 
-    connect( _tree, TQT_SIGNAL( finalizeLocal( KDirInfo * ) ),
-	     this,  TQT_SLOT  ( finalizeLocal( KDirInfo * ) ) );
+    connect( _tree, TQ_SIGNAL( finalizeLocal( KDirInfo * ) ),
+	     this,  TQ_SLOT  ( finalizeLocal( KDirInfo * ) ) );
 
-    connect( this,  TQT_SIGNAL( selectionChanged( KFileInfo * ) ),
-	     _tree, TQT_SLOT  ( selectItem      ( KFileInfo * ) ) );
+    connect( this,  TQ_SIGNAL( selectionChanged( KFileInfo * ) ),
+	     _tree, TQ_SLOT  ( selectItem      ( KFileInfo * ) ) );
 
-    connect( _tree, TQT_SIGNAL( selectionChanged( KFileInfo * ) ),
-	     this,  TQT_SLOT  ( selectItem      ( KFileInfo * ) ) );
+    connect( _tree, TQ_SIGNAL( selectionChanged( KFileInfo * ) ),
+	     this,  TQ_SLOT  ( selectItem      ( KFileInfo * ) ) );
 
     // Implicitly calling prepareReading() via the tree's startingReading() signal
     _tree->startReading( url );
@@ -269,11 +269,11 @@ KDirTreeView::prepareReading()
     if ( _updateTimer )
     {
 	_updateTimer->changeInterval( _updateInterval );
-	connect( _updateTimer,	TQT_SIGNAL( timeout() ),
-		 this,   	TQT_SLOT  ( updateSummary() ) );
+	connect( _updateTimer,	TQ_SIGNAL( timeout() ),
+		 this,   	TQ_SLOT  ( updateSummary() ) );
 
-	connect( _updateTimer, TQT_SIGNAL( timeout() ),
-		 this,   	TQT_SLOT  ( sendProgressInfo() ) );
+	connect( _updateTimer, TQ_SIGNAL( timeout() ),
+		 this,   	TQ_SLOT  ( sendProgressInfo() ) );
     }
 
 
@@ -734,7 +734,7 @@ KDirTreeView::ensureContrast()
 void
 KDirTreeView::paletteChanged()
 {
-    setTreeBackground( KGlobalSettings::baseColor() );
+    setTreeBackground( TDEGlobalSettings::baseColor() );
     ensureContrast();
 }
 
@@ -852,8 +852,8 @@ KDirTreeView::popupContextInfo( const TQPoint &	pos,
 void
 KDirTreeView::readConfig()
 {
-    KConfig *config = kapp->config();
-    KConfigGroupSaver saver( config, "Tree Colors" );
+    TDEConfig *config = kapp->config();
+    TDEConfigGroupSaver saver( config, "Tree Colors" );
     _usedFillColors = config->readNumEntry( "usedFillColors", -1 );
 
     if ( _usedFillColors < 0 )
@@ -887,8 +887,8 @@ KDirTreeView::readConfig()
 void
 KDirTreeView::saveConfig() const
 {
-    KConfig *config = kapp->config();
-    KConfigGroupSaver saver( config, "Tree Colors" );
+    TDEConfig *config = kapp->config();
+    TDEConfigGroupSaver saver( config, "Tree Colors" );
 
     config->writeEntry( "usedFillColors", _usedFillColors );
 
@@ -983,7 +983,7 @@ KDirTreeViewItem::KDirTreeViewItem( KDirTreeView *	view,
 				    KFileInfo *		orig )
     : TQListViewItem( parent )
 {
-    CHECK_PTR( parent );
+    TQ_CHECK_PTR( parent );
     init( view, parent, orig );
 }
 
@@ -1010,7 +1010,7 @@ KDirTreeViewItem::init( KDirTreeView *		view,
     }
     else
     {
-	setText( view->nameCol(), TQString::fromLocal8Bit(_orig->name()) );
+	setText( view->nameCol(), _orig->name() );
 
 	if ( ! _orig->isDevice() )
 	{
@@ -1526,9 +1526,9 @@ KDirTreeViewItem::asciiDump()
 {
     TQString dump;
 
-    dump.sprintf( "%10s  %s\n",
-		  (const char *) formatSize( _orig->totalSize() ),
-		  (const char *) _orig->debugUrl() );
+    dump = TQString("%1  %2\n")
+		.arg(formatSize(_orig->totalSize()), 10)
+		.arg(_orig->debugUrl().local8Bit());
 
     if ( isOpen() )
     {
@@ -1764,7 +1764,7 @@ KDirStat::formatSizeLong( KFileSize size )
 
 	if ( ++count == 3 && size > 0 )
 	{
-	    sizeText = KGlobal::locale()->thousandsSeparator() + sizeText;
+	    sizeText = TDEGlobal::locale()->thousandsSeparator() + sizeText;
 	    count = 0;
 	}
     }
@@ -1912,8 +1912,8 @@ KDirStat::localeTimeDate( time_t rawTime )
     TQDateTime timeDate;
     timeDate.setTime_t( rawTime );
     TQString timeDateString =
-	KGlobal::locale()->formatDate( timeDate.date(), true ) + "  " +	// short format
-	KGlobal::locale()->formatTime( timeDate.time(), true );		// include seconds
+	TDEGlobal::locale()->formatDate( timeDate.date(), true ) + "  " +	// short format
+	TDEGlobal::locale()->formatTime( timeDate.time(), true );		// include seconds
 
     return timeDateString;
 }
@@ -1940,7 +1940,7 @@ KDirStat::contrastingColor( const TQColor &desiredColor,
     }
 }
 
-
+#include "kdirtreeview.moc"
 
 
 
